@@ -50,8 +50,12 @@ KEduVocDocument::ErrorCode KEduVocKvtml2Reader::read(KEduVocDocument &doc)
 
     QDomDocument domDoc(QStringLiteral("KEduVocDocument"));
 
-    if (!domDoc.setContent(m_inputFile, &m_errorMessage))
+    const QDomDocument::ParseResult parseResult = domDoc.setContent(m_inputFile);
+    if (!parseResult) {
+        qDebug() << "Unable to load document.Parse error in line " << parseResult.errorLine << ", col " << parseResult.errorColumn << ": "
+                 << qPrintable(parseResult.errorMessage);
         return KEduVocDocument::InvalidXml;
+    }
 
     QDomElement domElementKvtml = domDoc.documentElement();
     if (domElementKvtml.tagName() != KVTML_TAG) {
